@@ -12,9 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from testtools import testcase as tc
+
+from tempest.lib import decorators
+from tempest.lib.common.utils import data_utils
+
 from sahara_tempest_plugin.tests.api import base as dp_base
-from tempest.common.utils import data_utils
-from tempest import test
 
 
 class JobBinaryTest(dp_base.BaseDataProcessingTest):
@@ -69,13 +72,13 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
 
         return resp_body['id'], binary_name
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('c00d43f8-4360-45f8-b280-af1a201b12d3')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('c00d43f8-4360-45f8-b280-af1a201b12d3')
     def test_swift_job_binary_create(self):
         self._create_job_binary(self.swift_job_binary_with_extra)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('f8809352-e79d-4748-9359-ce1efce89f2a')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('f8809352-e79d-4748-9359-ce1efce89f2a')
     def test_swift_job_binary_list(self):
         binary_info = self._create_job_binary(self.swift_job_binary_with_extra)
 
@@ -84,8 +87,8 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
         binaries_info = [(binary['id'], binary['name']) for binary in binaries]
         self.assertIn(binary_info, binaries_info)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('2d4a670f-e8f1-413c-b5ac-50c1bfe9e1b1')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('2d4a670f-e8f1-413c-b5ac-50c1bfe9e1b1')
     def test_swift_job_binary_get(self):
         binary_id, binary_name = (
             self._create_job_binary(self.swift_job_binary_with_extra))
@@ -95,8 +98,8 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
         self.assertEqual(binary_name, binary['name'])
         self.assertDictContainsSubset(self.swift_job_binary, binary)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('9b0e8f38-04f3-4616-b399-cfa7eb2677ed')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('9b0e8f38-04f3-4616-b399-cfa7eb2677ed')
     def test_swift_job_binary_delete(self):
         binary_id, _ = (
             self._create_job_binary(self.swift_job_binary_with_extra))
@@ -104,13 +107,13 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
         # delete the job binary by id
         self.client.delete_job_binary(binary_id)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('63662f6d-8291-407e-a6fc-f654522ebab6')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('63662f6d-8291-407e-a6fc-f654522ebab6')
     def test_internal_db_job_binary_create(self):
         self._create_job_binary(self.internal_db_job_binary)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('38731e7b-6d9d-4ffa-8fd1-193c453e88b1')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('38731e7b-6d9d-4ffa-8fd1-193c453e88b1')
     def test_internal_db_job_binary_list(self):
         binary_info = self._create_job_binary(self.internal_db_job_binary)
 
@@ -119,8 +122,8 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
         binaries_info = [(binary['id'], binary['name']) for binary in binaries]
         self.assertIn(binary_info, binaries_info)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('1b32199b-c3f5-43e1-a37a-3797e57b7066')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('1b32199b-c3f5-43e1-a37a-3797e57b7066')
     def test_internal_db_job_binary_get(self):
         binary_id, binary_name = (
             self._create_job_binary(self.internal_db_job_binary))
@@ -130,8 +133,8 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
         self.assertEqual(binary_name, binary['name'])
         self.assertDictContainsSubset(self.internal_db_job_binary, binary)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('3c42b0c3-3e03-46a5-adf0-df0650271a4e')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('3c42b0c3-3e03-46a5-adf0-df0650271a4e')
     def test_internal_db_job_binary_delete(self):
         binary_id, _ = self._create_job_binary(self.internal_db_job_binary)
 
@@ -143,8 +146,8 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
         binaries_ids = [binary['id'] for binary in binaries]
         self.assertNotIn(binary_id, binaries_ids)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('d5d47659-7e2c-4ea7-b292-5b3e559e8587')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('d5d47659-7e2c-4ea7-b292-5b3e559e8587')
     def test_job_binary_get_data(self):
         binary_id, _ = self._create_job_binary(self.internal_db_job_binary)
 
